pub fn parse_levels_raw(raw: &str) -> ParsedLevelsExpand description
Read the levels field: a bare number is a count, anything else is a list of level texts.
pub fn parse_levels_raw(raw: &str) -> ParsedLevelsRead the levels field: a bare number is a count, anything else is a list of level texts.